#include<ros/ros.h>
#include<geometry_msgs/Twist.h>
#include<sensor_msgs/Joy.h>
#include<iostream>

#define QUEUE_SIZE 64 //subscriber buffer size

using namespace std;
float max_linear_vel = 1.0;
float max_angular_vel = 1.0;

class TeleopJoy{
public:
  TeleopJoy();
private:
  void callBack(const sensor_msgs::Joy::ConstPtr& joy);
  ros::NodeHandle n;
  ros::Publisher pub;
  ros::Subscriber sub;
  int i_velLinear , i_velAngular;
};

TeleopJoy::TeleopJoy()
{   i_velLinear = 1;
	i_velAngular = 0; 
	n.param("axis_linear", i_velLinear, i_velLinear);
	n.param("axis_angular", i_velAngular, i_velAngular);
	pub = n.advertise<geometry_msgs::Twist>("cmd_vel", 1);
	sub = n.subscribe<sensor_msgs::Joy>("joy", QUEUE_SIZE, &TeleopJoy::callBack, this);
}

void TeleopJoy::callBack(const sensor_msgs::Joy::ConstPtr& joy)
{
	geometry_msgs::Twist vel;
	vel.angular.z = -max_angular_vel*joy->axes[2]; // right handle left-to-right
	vel.linear.x = max_linear_vel*joy->axes[3]; // right handle up
	pub.publish(vel);
}

int main(int argc, char** argv)
{
	ros::init(argc, argv, "rofish_teleop_joy");
	TeleopJoy teleop_robot;
	ros::spin();
}
